# ABSESpy: Agent-Based Modeling Framework for Social-Ecological Systems

![ABSES_banner](https://songshgeo-picgo-1302043007.cos.ap-beijing.myqcloud.com/uPic/CleanShot%202023-10-19%20at%2019.08.12@2x.png)

<div align="center"><p>
    <a href="https://github.com/absespy/ABSESpy/releases/latest">
        <img alt="Latest release" src="https://img.shields.io/github/v/release/absespy/ABSESpy?style=for-the-badge&logo=probot&color=C9CBFF&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/absespy/ABSESpy/pulse">
        <img alt="Last commit" src="https://img.shields.io/github/last-commit/absespy/ABSESpy?style=for-the-badge&logo=probot&color=8bd5ca&logoColor=D9E0EE&labelColor=302D41"/>
    </a>
    <a href="https://github.com/absespy/ABSESpy/blob/main/LICENSE">
        <img alt="License" src="https://img.shields.io/github/license/absespy/ABSESpy?style=for-the-badge&logo=probot&color=ee999f&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/absespy/ABSESpy/stargazers">
        <img alt="Stars" src="https://img.shields.io/github/stars/absespy/ABSESpy?style=for-the-badge&logo=probot&color=c69ff5&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/absespy/ABSESpy/issues">
        <img alt="Issues" src="https://img.shields.io/github/issues/absespy/ABSESpy?style=for-the-badge&logo=probot&color=F5E0DC&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/absespy/ABSESpy">
        <img alt="Repo Size" src="https://img.shields.io/github/repo-size/absespy/ABSESpy?color=%23DDB6F2&label=SIZE&logo=codesandbox&style=for-the-badge&logoColor=D9E0EE&labelColor=302D41" />
    </a>

<a href="https://twitter.com/intent/follow?screen_name=shuangsong11">
    <img alt="follow on Twitter" src="https://img.shields.io/twitter/follow/shuangsong11?style=for-the-badge&logo=twitter&color=8aadf3&logoColor=D9E0EE&labelColor=302D41" />
</a>

<!-- Website Badge -->
<a href="https://cv.songshgeo.com/">
    <img src="https://img.shields.io/badge/Website-SongshGeo-brightgreen.svg?style=for-the-badge&logo=twitter&color=8aadf3&logoColor=D9E0EE&labelColor=302D41" alt="github">
</a>

  <!-- <p align="center">
    <img src="https://stars.medv.io/absespy/ABSESpy.svg", title="commits"/>
  </p> -->

---
Language: [English Readme] | [简体中文]

**[<kbd> <br> Install <br> </kbd>][Install]**
**[<kbd> <br> Getting started <br> </kbd>][Getting Started]**
**[<kbd> <br> Tutorials <br> </kbd>][Tutorials]**
**[<kbd> <br> Contribute <br> </kbd>][Contribute]**

</div>

`ABSESpy` is an agent-based modeling (ABM) framework based on [Mesa], but it focus more on simulating real-world problems.
Tailored specifically for social-ecological systems (SES), or coupled human-nature systems, `ABSESpy` simplifies the interactions between agents and their grid-like environment.
Its ultimate objective is to become the go-to choice for agent-based modeling when working with human-involved environment changes.

## Features

<img src="https://songshgeo-picgo-1302043007.cos.ap-beijing.myqcloud.com/uPic/ABSESpy%20API.jpg" alt="ABSESpy API structure" style="max-width:400px;max-height:400px;width:auto;height:auto;">


- 🌍 Modeling social-ecological system with geo-data.
- 🤖 Managing and manipulating agents with ease of cake.
- 🕙 Make your model coherent with real-world time.
- 📁 Handling complex models with a configuration file.
- 🙋 and more...

## Thanks to all contributors

<div align="center"><p>
<a href="https://github.com/ABSESpy/ABSESpy/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=ABSESpy/ABSESpy" />
</a>
</div>

  [Mesa]: https://github.com/projectmesa/mesa
  [Contribute]: https://absespy.github.io/ABSESpy/home/contribution/
  [Getting Started]: https://absespy.github.io/ABSESpy/home/get_started/
  [Install]: https://absespy.github.io/ABSESpy/home/Installation/
  [Tutorials]: https://absespy.github.io/ABSESpy/tutorial/tutorial/
  [简体中文]: README.zh-cn.md
  [English Readme]: README.md
